@@ -1,11 +1,11 @@
 `ddst.norm.Nk` <-
 function(x, base = ddst.base.legendre, Dmax = 5, n=length(x)) {
-er1 = .Internal(mean(x))
+er1 = mean(x)
 sx  = sort(x)
 H   = qnorm((1:n - 3/8)/(n+1/4))
-er2 = .Internal(mean((sx[-1] - sx[-n])/(H[-1] - H[-n])))
+er2 = mean((sx[-1] - sx[-n])/(H[-1] - H[-n]))
 pp   = (x-er1)/er2
-tmpp = c(.Internal(mean(pp)), (.Internal(mean(pp^2)) - 1)/2)
+tmpp = c(mean(pp), (mean(pp^2) - 1)/2)
 maxN = max(min(Dmax, length(x)-2, 20),1)
 u = numeric(maxN)
 for (j in 1:maxN) 
